fflas_ffpack: Dense linear algebra over word-size finite fields
===============================================================

Description
-----------

FFLAS-FFPACK is a LGPL-2.1+ source code library for dense linear algebra
over word-size finite fields.

http://linbox-team.github.io/fflas-ffpack/

License
-------

LGPL V2.1 or later


Upstream Contact
----------------

-  <ffpack-devel@googlegroups.com>
